@@ -163,17 +163,18 @@ def check_alignment(alignment_length, gff_ranges):
   if alignment_length < max_pos:
     sys.exit(f'The maximum position {max_pos} specified in the GFF file exceeds the alignment length')
 
-def find_pseudo_alignment_length(pseudogenome_alignment_path):
-  with open(pseudogenome_alignment_path) as input_alignment:
+def find_fasta_length(fasta_path):
+  with open(fasta_path) as input_alignment:
     current_sequence = ""
     for line in input_alignment:
       if line.startswith(">"):
         if current_sequence != "":
-          return(len(current_sequence))
+          return(len(current_sequence)) # Multiple fasta sequence
         else: # first sequence
           next
       else:
         current_sequence += line.strip()
+    return(len(current_sequence)) # Single fasta sequence
 
 def mask_sequence(sequence, gff_ranges, masking_character):
   for gff_range in gff_ranges:
@@ -183,14 +184,14 @@ def mask_sequence(sequence, gff_ranges, masking_character):
     sequence = f'{sequence[:start]}{masking_character*difference}{sequence  [end:]}'
   return(sequence)
 
-def mask_mges(pseudogenome_alignment_path, gff_file_path, masking_character):
+def mask_mges(fasta_path, gff_file_path, masking_character):
   # find length of pseudoalignment
-  alignment_length = find_pseudo_alignment_length(pseudogenome_alignment_path)  
+  alignment_length = find_fasta_length(fasta_path)  
   gff_ranges = extract_position_ranges_from_gff_file(gff_file_path)
   check_alignment(alignment_length, gff_ranges)
 
-  masked_pseudogenome_alignment_path = Path(pseudogenome_alignment_path).with_suffix('.masked.fas') 
-  with open(pseudogenome_alignment_path) as input_alignment, open(masked_pseudogenome_alignment_path, 'w') as output_alignment:
+  masked_fasta_path = Path(fasta_path).with_suffix('.masked.fas') 
+  with open(fasta_path) as input_alignment, open(masked_fasta_path, 'w') as output_alignment:
     sequence = ""
     index = 0
     for line in input_alignment:
@@ -217,7 +218,7 @@ def mask_mges(pseudogenome_alignment_path, gff_file_path, masking_character):
       record = SeqRecord(Seq(sequence), id=id, description = "")
     output_alignment.write(record.format("fasta"))
 
-  return(masked_pseudogenome_alignment_path)
+  return(masked_fasta_path)
   
 
 def print_default_regex_patterns():
